/** @module Webinar */
import { Subject, Subscription } from "rxjs";
import { Contact } from '../models/contact.model';
import { Bubble } from '../models/bubble.model';
import { JingleSession } from "../libs/strophe/strophe.jingle.session";
/**
 * Webinar status
 */
export declare enum WebinarStatus {
    UPCOMING = "upcoming",
    WAITING_ROOM = "waitingRoom",
    PRACTICE_ROOM = "practiceRoom",
    PRACTICE_WAITING_ROOM = "practiceWaitingRoom",
    IN_PROGRESS = "inProgress",
    TERMINATED = "terminated"
}
export declare enum WebinarMediaType {
    participant = "participant",
    sharing = "sharing",
    mix = "mix"
}
export interface WebinarCodecs {
    audio?: string;
    video?: string;
    sharing?: string;
}
export declare enum WebinarSessionParticipantEvents {
    UPDATE_PARTICIPANT = "updateParticipant"
}
export declare class WebinarSessionParticipant {
    id: string;
    contact: Contact;
    activeSpeaker: boolean;
    mute: boolean;
    onStage: boolean;
    sharingOnStage: boolean;
    searchString: string;
    role: string;
    raiseHand: boolean;
    raiseHandDate?: Date;
    raiseHandPosition?: number;
    allowedToTalk: boolean;
    invitedToTalk: boolean;
    audioConfig: string;
    audible: boolean;
    audioVideoSession: any;
    originalAudioVideoStream: MediaStream;
    audioVideoStream: MediaStream;
    sharingSession: any;
    sharingStream: any;
    medias: any;
    rxSubject: Subject<any>;
    subStreamLevel: number;
    temporalLevel: number;
    static create(id: string): WebinarSessionParticipant;
    constructor(id: string);
    sendEvent(event: WebinarSessionParticipantEvents): void;
    getSessionType(sessionId: string): string | null;
    onHold(media: 'video' | 'sharing'): boolean;
}
export declare class WebinarSessionService {
    id: string;
    type: string;
    sid?: string;
    audioVideoSession?: JingleSession;
    audioVideoStream?: MediaStream;
    static create(id: string, name: string): WebinarSessionService;
    constructor(id: string, type: string);
}
export declare class WebinarSession {
    jingleJid: string;
    activeSpeakerId: string;
    localParticipant: WebinarSessionParticipant;
    speakerParticipants: WebinarSessionParticipant[];
    attendeeParticipants: WebinarSessionParticipant[];
    raiseHandAttendeeParticipants: WebinarSessionParticipant[];
    service?: WebinarSessionService;
    connected: boolean;
    masterMedia: string;
    showMySharing: boolean;
    static create(): WebinarSession;
    getParticipantById(participantId: string): WebinarSessionParticipant;
    getSpeakerBySessionId(sessionId: string): WebinarSessionParticipant;
    addOrUpdateParticipant(participant: WebinarSessionParticipant, action?: string): void;
    removeParticipant(participantId: string): void;
    addService(serviceId: string, serviceName: string): WebinarSessionService;
}
export declare class WebinarParticipant {
    email: string;
    lastName: string;
    firstName: string;
    company: string;
    jobTitle: string;
    state: string;
    userId: string;
    lastAvatarUpdateDate: string;
    country: string;
    static create(): WebinarParticipant;
    static createFromData(data: any): WebinarParticipant;
    getData(): string;
}
export declare class WebinarCSVStatus {
    errorDetails: string;
    okCount: number;
    errorCount: number;
    errorReport: any;
    static create(): WebinarCSVStatus;
}
/**
 * @eventProperty
 * `Webinar` specific events
 */
export declare enum WebinarEvents {
    /**
     * @eventProperty
     * This RBEvent is send when the webinar status change
     */
    ON_STATUS_CHANGE = "ON_STATUS_CHANGE",
    /**
     * @eventProperty
     * This RBEvent is send when
     */
    ON_DATA_UPDATE = "ON_DATA_UPDATED",
    /**
     * @eventProperty
     * This RBEvent is send when
     */
    ON_AVATAR_UPDATE = "ON_AVATAR_UPDATE",
    /**
     * @eventProperty
     * This RBEvent is send when
     */
    ON_LOGO_UPDATE = "ON_LOGO_UPDATE",
    /**
     * @eventProperty
     * This RBEvent is send when
     */
    ON_CHAT_OPTIONS_UPDATE = "ON_CHAT_OPTIONS_UPDATE"
}
export interface Webinar {
    id: string;
    name: string;
    subject: string;
    webinarStartDate: string;
    webinarEndDate: string;
    webinarDuration: string;
    webinarLastDateCheck: string;
    waitingRoomStartDate: string;
    timeZone: string;
    roomId: string;
    roomModeratorsChatId: string;
    room: Bubble;
    practiceRoom: Bubble;
    organizers: any[];
    speakers: any[];
    participants: WebinarParticipant[];
    profileId: string;
    pendingParticipantNumber: number;
    acceptedParticipantNumber: number;
    rejectedParticipantNumber: number;
    color: string;
    creatorId: string;
    creatorCompanyId: string;
    isCreator: boolean;
    isOrganizer: boolean;
    isSpeaker: boolean;
    isAttendee: boolean;
    isGuestAttendee: boolean;
    isGuest: boolean;
    password: string;
    approvalRegistrationMethod: string;
    registrationUuid: string;
    published: boolean;
    moderatorsNotified: boolean;
    status: WebinarStatus;
    webinarUrl: string;
    rxSubject: Subject<any>;
    rxAskStagingSubject: Subject<any>;
    rxParticipantsSubject: Subject<any>;
    rxServiceSubject: Subject<any>;
    rxInfoSubject: Subject<any>;
    isWebinarSync: boolean;
    session: WebinarSession | null;
    waitingRoomMultimediaURLs: string[];
    stageBackground: string;
    reminderDates: string[];
    subtitlesEnable: boolean;
    blur: boolean;
    bgReplaceUrl: string;
    chatOption: string;
    chatOptionExpired: boolean;
    chatOptionTimer: any;
    recorded?: string;
    hideRecordInfo: boolean;
    recordFileId: string;
    recordStatus: string;
    action: string;
    lastAvatarUpdate?: string;
    lastActorsInfo?: any;
    incomingStreamsDisabled: any;
    sendEvent(name: WebinarEvents, data?: any): void;
    subscribe(handler: any): Subscription;
    updateAttendeeCounters(): void;
    getData(): string;
    updateRaiseHandParticipants(): void;
    isTerminated(): boolean;
    isWaitingRoomStarted(): boolean;
    isInvitation(): boolean;
    /**
     * Asynchronous method to update webinar avatar on server
     * @param avatarImg - base64 encoded webinar avatar
     */
    updateAvatar(avatarSrc: string): Promise<Webinar>;
    /**
    * Asynchronous method to update webinar logo on server
    * @param logoSrc - base64 encoded webinar logo
    */
    updateLogo(logoSrc: string): Promise<Webinar>;
    /**
     * Allow a rainbow attendee to join the webinar room
     */
    joinAsRainbowAttendee(): Promise<void>;
    /**
     * Allow a rainbow user to join the webinar
     */
    join(): Promise<void>;
    /**
    * Allow to leave a webinar
    *  - remove the user from the stage (if it was on the stage)
    *  - remove the user from the conference (stop the session if last user)
    * @param forced - when set to true this method stop the session (even if not the last user connect in conf)
    * @param nowait - when set to true this method call async child methods without waiting the end of execution (used in last chance deconnection event mechanism (onunload event))
    * @returns A promise that is resolved when the user has join the conference
    */
    leave(forced?: boolean, nowait?: boolean): Promise<void>;
    /**
     * Update existing webinar with server data
     * @param webinarData - server webinar data structure
     */
    updateFromData(webinarData: any): void;
    /**
     * Accept webinar invitation (as a speaker)
     */
    acceptInvitation(): Promise<void>;
    /**
     * Add audio/video media
     * @param media - the media to add
     */
    addAudioVideoMedia(media: string, stream?: MediaStream, replaceBg?: boolean): Promise<void>;
    /**
     * Add a sharing media
     * @param stream - the mediaStream to add as sharing media
     */
    addSharingMedia(stream: MediaStream): Promise<void>;
    /**
     * Put local participant audio/video media on stage
     * @param master - when set to true the participant media is presented on master
     */
    putLocalParticipantAudioVideoMediaOnStage(master?: boolean): Promise<Webinar>;
    /**
     * Put a participant sharing media on stage
     * @param master - when set to true the participant sharing is presented on master
     */
    putParticipantSharingMediaOnStage(participant: WebinarSessionParticipant, master?: boolean): Promise<Webinar>;
    /**
     * Remove a participant audio/video media from the stage
     * @param participant - the participant to remove from the stage
     */
    removeParticipantAudioVideoMediaFromStage(participant: WebinarSessionParticipant): Promise<Webinar>;
    /**
     * Remove a participant sharing media from the stage
     * @param participant - the participant to remove from the stage
     */
    removeParticipantSharingMediaFromStage(participant: WebinarSessionParticipant): Promise<Webinar>;
    /**
     * Share the local participant audioConfig
     * @param audioConfig - the audioConfig "stage"|"backstage"|"stageAndBackstage"|a userId
     */
    shareLocalParticipantAudioConfig(audioConfig: string): Promise<Webinar>;
}
export declare class WebinarRB implements Webinar {
    private webinarService?;
    id: string;
    name: string;
    subject: string;
    webinarStartDate: string;
    webinarEndDate: string;
    webinarDuration: string;
    webinarLastDateCheck: string;
    waitingRoomStartDate: string;
    timeZone: string;
    roomId: string;
    roomModeratorsChatId: string;
    room: Bubble;
    practiceRoom: Bubble;
    organizers: any[];
    speakers: any[];
    participants: WebinarParticipant[];
    profileId: string;
    pendingParticipantNumber: number;
    acceptedParticipantNumber: number;
    rejectedParticipantNumber: number;
    color: string;
    creatorId: string;
    creatorCompanyId: string;
    isCreator: boolean;
    isOrganizer: boolean;
    isSpeaker: boolean;
    isAttendee: boolean;
    isGuestAttendee: boolean;
    isGuest: boolean;
    password: string;
    approvalRegistrationMethod: string;
    registrationUuid: string;
    published: boolean;
    moderatorsNotified: boolean;
    status: WebinarStatus;
    webinarUrl: string;
    rxSubject: Subject<any>;
    rxAskStagingSubject: Subject<any>;
    rxParticipantsSubject: Subject<any>;
    rxServiceSubject: Subject<any>;
    rxInfoSubject: Subject<any>;
    isWebinarSync: boolean;
    session: WebinarSession | null;
    waitingRoomMultimediaURLs: string[];
    stageBackground: string;
    reminderDates: string[];
    subtitlesEnable: boolean;
    blur: boolean;
    bgReplaceUrl: string;
    chatOption: string;
    chatOptionExpired: boolean;
    chatOptionTimer: any;
    recorded?: string;
    hideRecordInfo: boolean;
    recordFileId: string;
    recordStatus: string;
    action: string;
    lastAvatarUpdate?: string;
    lastActorsInfo?: any;
    incomingStreamsDisabled: any;
    private constructor();
    static create(): WebinarRB;
    static createFromData(webinarData: any): WebinarRB;
    sendEvent(name: WebinarEvents, data?: any): void;
    /**
     * Update existing webinar with server data
     * @param webinarData - server webinar data structure
     */
    updateFromData(webinarData: any): void;
    updateAttendeeCounters(): void;
    subscribe(handler: any): Subscription;
    getData(): string;
    updateRaiseHandParticipants(): void;
    isTerminated(): boolean;
    isWaitingRoomStarted(): boolean;
    isInvitation(): boolean;
    /**
     * Asynchronous method to update webinar avatar on server
     * @param avatarImg - base64 encoded webinar avatar
     */
    updateAvatar(avatarSrc: string): Promise<Webinar>;
    /**
     * Asynchronous method to update webinar logo on server
     * @param logoSrc - base64 encoded webinar logo
     */
    updateLogo(logoSrc: string): Promise<Webinar>;
    acceptInvitation(): Promise<void>;
    join(): Promise<void>;
    addAudioVideoMedia(media: string, stream?: MediaStream, replaceBg?: boolean): Promise<void>;
    addSharingMedia(stream: MediaStream): Promise<void>;
    leave(forced?: boolean, nowait?: boolean): Promise<void>;
    joinAsRainbowAttendee(): Promise<void>;
    putLocalParticipantAudioVideoMediaOnStage(master?: boolean): Promise<Webinar>;
    putParticipantSharingMediaOnStage(participant: WebinarSessionParticipant, master?: boolean): Promise<Webinar>;
    removeParticipantAudioVideoMediaFromStage(participant: WebinarSessionParticipant): Promise<Webinar>;
    removeParticipantSharingMediaFromStage(participant: WebinarSessionParticipant): Promise<Webinar>;
    shareLocalParticipantAudioConfig(audioConfig: string): Promise<Webinar>;
}
//# sourceMappingURL=webinar.model.d.ts.map