/**
 * @module RainbowSDK
 */
import './strophejs';
import { SDKPlugin } from './plugins/plugin';
import { ConnectionService } from './services/core/connection.service';
import { LogLevelEnum } from './services/core/logger.service';
import { UserNetworkService } from './services/core/userNetwork.service';
import { BubbleConferenceService, ConversationService, DirectorySearchService } from './services';
import { ConnectedUser } from './models';
import { UtilitiesService } from './services/utilities/utilities.service';
import { BubbleService } from './services/bubbles';
import { WebinarService } from './services/webinars/webinars.service';
import { CallService } from './services/call/call.service';
import { FavoritesService } from './services/favorites/favorites.service';
import { CallLogService } from './services/callLog/callLog.service';
import { DataChannelService } from './services/dataChannel';
import { DeviceManagementService } from './services/deviceManagement/deviceManagement.service';
import { TelephonyConfigService } from './services/telephonyConfig';
import { SDKAdminService } from './services/admin';
import { BubbleTagService } from './services/bubbles/bubbleTag.service';
import { UserService } from './services/users/user.service';
import { DocumentsService } from './services/documents/documents.service';
import { LiveTranscriptionService } from './services/transcription/liveTranscription.service';
export interface RainbowSDKAppConfig {
    /** Rainbow backend server url */
    server?: string;
    /** Rainbow application identifier */
    applicationId?: string;
    /** Rainbow application secretKey */
    secretKey?: string;
}
export interface RainbowSDKConfig {
    /** Application configuration */
    appConfig?: RainbowSDKAppConfig;
    /** List of plugins to use in the application */
    plugins?: SDKPlugin[];
    /** When set to true, the sdk will try to connect with localStorage token information */
    autoLogin?: boolean;
    /** Specify the SDK internal log level */
    logLevel?: LogLevelEnum;
    /** When set to true, sone additional CONNECTING events will be emitted to manage a connection progress bar */
    progressEvents?: boolean;
    /** @internal */
    devMode?: boolean;
}
/**
 * This class is the **Web Rainbow SDK** main entry point
 * It offers :
 * + Lifecycle methods (create, start and stop methods)
 * + A get method to fetch plugin services
 * + Direct accesses to "core" plugins
 */
export declare class RainbowSDK {
    /**
     * Direct access to core ConnectedUser
     * @returns the ConnectedUser instance
     */
    get connectedUser(): ConnectedUser | undefined;
    /**
     * Direct access to core ConnectionService
     * @returns the ConnectionService singleton instance
     */
    get connectionService(): ConnectionService;
    /**
      * Direct access to core ConversationService
      * @returns the ConversationService singleton instance if available
      */
    get conversationService(): ConversationService;
    /**
     * Direct access to core UserService
     * @returns the UserService singleton instance
     */
    get userService(): UserService;
    /**
     * Direct access to core UtilitiesService
     * @returns the UtilitiesService singleton instance
     */
    get utils(): UtilitiesService;
    /**
     * Direct access to core UserNetworkService
     * @returns the UserNetworkService singleton instance
     */
    get userNetwork(): UserNetworkService;
    /**
     * Direct access to BubbleService
     * @returns the BubbleService singleton instance if available
     */
    get bubbleService(): BubbleService | undefined;
    /**
     * Direct access to BubbleTagService
     * @returns the BubbleService singleton instance if available
     */
    get BubbleTagService(): BubbleTagService | undefined;
    /**
     * Direct access to WebinarService
     * @returns the WebinarService singleton instance if available
     */
    get webinarService(): WebinarService | undefined;
    /**
     * Direct access to DocumentsService
     * @returns the DocumentsService singleton instance if available
     */
    get documentsService(): DocumentsService | undefined;
    /**
     * Direct access to core DirectoryService
     * @returns the DirectoryService singleton instance
     */
    get directorySearchService(): DirectorySearchService;
    /**
     * Direct access to CallService
     * @returns the CallService singleton instance if available
     */
    get callService(): CallService | undefined;
    /**
     * Direct access to FavoritesService
     * @returns the FavoritesService singleton instance if available
     */
    get favoritesService(): FavoritesService | undefined;
    /**
     * Direct access to CallLogService
     * @returns the CallLogService singleton instance if available
     */
    get callLogsService(): CallLogService | undefined;
    /**
     * Direct access to BubbleConferenceService
     * @returns the BubbleConferenceService singleton instance if available
     */
    get bubbleConferenceService(): BubbleConferenceService | undefined;
    /**
     * Direct access to DataChannelService
     * @returns the DataChannelService singleton instance if available
     */
    get dataChannelService(): DataChannelService | undefined;
    /**
     * Direct access to DeviceManagementService
     * @returns the DeviceManagementService singleton instance if available
     */
    get deviceManagementService(): DeviceManagementService | undefined;
    /**
     * Direct access to TelephonyConfigService
     * @returns the TelephonyConfigService singleton instance if available
     */
    get telephonyConfigService(): TelephonyConfigService | undefined;
    /**
     * Direct access to TranscriptionService
     * @returns the TranscriptionService singleton instance if available
     */
    get transcriptionService(): LiveTranscriptionService | undefined;
    /**
     * Direct access to AdminService
     * @returns the AdminService singleton instance if available
     */
    get adminService(): SDKAdminService | undefined;
    private _contactService;
    private _userService;
    private _loggerService;
    private _connectionService;
    private _utilitiesService;
    private _conversationService;
    private _directorySearchService;
    /**
     * Static method to reach the RainbowSDK singleton instance
     * @returns The Rainbow singleton instance
     */
    static getInstance(): RainbowSDK;
    /**
     * Static method to create the RainbowSDK singleton instance
     * @returns The Rainbow singleton instance
     */
    static create(options?: RainbowSDKConfig): RainbowSDK;
    private constructor();
    /**
     * Permits to enable console logs
     * @param enable - when set to true logs are displayed on console
     */
    enableLogs(enable: boolean): void;
    /**
     * Permits to specify logLevel
     * @param logLevel - when set to true logs are displayed on console
     */
    setLogLevel(logLevel: LogLevelEnum): void;
    /**
     * Permits to get current logLevel
     * @param logLevel - when set to true logs are displayed on console
     */
    getLogLevel(): LogLevelEnum;
    /**
     * Permits to start the Rainbow SDK
     * @returns resolve when Rainbow SDK is started
     */
    start(): Promise<ConnectedUser>;
    /**
    * Permits to stop the Rainbow SDK
    * @returns resolve when Rainbow SDK is stopped
    */
    stop(): Promise<void>;
    /**
    * Get the current Rainbow SDK version
    * @returns the current Rainbow SDK version
    */
    getVersion(): string;
    /**
    * Permit to fetch the singleton instance of a named service
    * @returns the singleton instance of a named service
    */
    get<T = any>(serviceName: string): T | undefined;
}
//# sourceMappingURL=rainbow.sdk.d.ts.map