import { BubbleConferenceRecap } from '../../models/bubbleConferenceRecap.model';
import { FileDescriptor } from '../../models/common/fileDescriptor';
import { Service } from '../../services/service';
import { Bubble, BubbleConference, RBEvent } from '../../index';
import { Subscription } from 'rxjs';
/** @internal */
export declare const CONFERENCE_RECORDING_SVC = "ConferenceRecordingService";
/**
 * @eventProperty
 * `BubbleConferenceRecordingService` specific events
 */
export declare enum BubbleConferenceRecordingServiceEvents {
    /**
     * @eventProperty
     * This `RBEvent` is sent when a new conference recording is ready
     */
    ON_WEBCONFERENCERECORDING_CREATED = "ON_WEBCONFERENCERECORDING_CREATED",
    /**
     * @eventProperty
     * This `RBEvent` is sent when a new conference recording is ready
     */
    ON_WEBCONFERENCERECORDING_READY = "ON_WEBCONFERENCERECORDING_READY",
    /**
     * @eventProperty
     * This `RBEvent` is sent when a conference recording is shared
     */
    ON_WEBCONFERENCERECORDING_SHARED = "ON_WEBCONFERENCERECORDING_SHARED",
    /**
     * @eventProperty
     * This `RBEvent` is sent when a conference recording is removed
     */
    ON_WEBCONFERENCERECORDING_REMOVED = "ON_WEBCONFERENCERECORDING_REMOVED"
}
export declare class BubbleConferenceRecordingStartParams {
    transcription: boolean;
    summary: boolean;
    summaryForm: 'paragraph' | 'bullet';
    persistent: boolean;
    inputLangage: string;
}
export interface BubbleConferenceRecordingService {
    /**
     * Subscribe to BubbleConferenceRecording service events
     * @param handler - The handler function that will be called on events
     * @param eventNames - The events to subscribe to
     */
    subscribe(handler: (event: RBEvent<BubbleConferenceRecordingServiceEvents>) => any, eventNames?: BubbleConferenceRecordingServiceEvents | BubbleConferenceRecordingServiceEvents[]): Subscription;
    /**
     * Start recording a conference.
     * @param bubbleConference - the conference to record
     */
    startRecording(bubbleConference: BubbleConference, params?: BubbleConferenceRecordingStartParams): Promise<void>;
    /**
     * Pause recording a conference.
     * @param bubbleConference - the conference to record
     */
    pauseRecording(bubbleConference: BubbleConference): Promise<void>;
    /**
     * Resume recording a conference.
     * @param bubbleConference - the conference to record
     */
    resumeRecording(bubbleConference: BubbleConference): Promise<void>;
    /**
     * Stop recording a conference.
     * @param bubbleConference - the conference to record
     */
    stopRecording(bubbleConference: BubbleConference): Promise<void>;
    /**
     * Get all conference recaps that belong to the connected user
     */
    getConferenceRecaps(bubble?: Bubble): Promise<BubbleConferenceRecap[]>;
    /**
     * Get conference recaps shared with the connected user
     */
    getSharedWithMeConferenceRecaps(bubble?: Bubble): Promise<BubbleConferenceRecap[]>;
    getSharedWithMeConferenceRecordingFilesOld(bubble?: Bubble): Promise<FileDescriptor[]>;
    /**
     * Delete conference recap
     * @param conferenceRecap- the conference recap to remove
     */
    deleteConferenceRecap(conferenceRecap: BubbleConferenceRecap): Promise<void>;
    /**
     * Delete conference recording file
     * @param conferenceRecordingFileId - ID of the conference recording file (note: not file descriptor ID)
     */
    deleteConferenceRecordingFile(conferenceRecordingFileId: string): Promise<void>;
    /**
     * Fetch conference recording's associated files from the server.
     * Returns an array of all the files associated to the recording (.mp4, .m4a, .png and .txt)
     * @param conferenceRecordingFile - Conference recording file
     */
    getConferenceRecordingAssociatedFiles(conferenceRecordingFile: BubbleConferenceRecap): Promise<FileDescriptor[]>;
}
/**
 * The module is responsible for recording web conferences.
 * @internal
 */
export declare class ConferenceRecordingServiceRB extends Service implements BubbleConferenceRecordingService {
    private authService;
    private logger;
    private xmppService;
    private contactService;
    private bubbleService;
    private fileStorageService;
    private fileServerService;
    private errorHelperService;
    private settingsService;
    private getConferenceRecordingFilesPromises;
    private getSharedWithMeConferenceRecordingFilesPromises;
    private getSharedWithMeConferenceRecordingFilesOldPromises;
    private eventsSubject;
    private recordingFiles?;
    private sharedRecordingFiles?;
    private sharedRecordingFilesOld?;
    private subscription;
    private messageHandlerRef?;
    static getInstance(): ConferenceRecordingServiceRB;
    static build(): ConferenceRecordingServiceRB;
    protected constructor();
    start(): Promise<void>;
    stop(): Promise<void>;
    reconnect(): Promise<void>;
    subscribe(handler: (event: RBEvent<BubbleConferenceRecordingServiceEvents>) => any, eventNames?: BubbleConferenceRecordingServiceEvents | BubbleConferenceRecordingServiceEvents[]): Subscription;
    private sendEvent;
    private attachEventListeners;
    startRecording(bubbleConference: BubbleConference, params?: BubbleConferenceRecordingStartParams): Promise<void>;
    pauseRecording(bubbleConference: BubbleConference): Promise<void>;
    resumeRecording(bubbleConference: BubbleConference): Promise<void>;
    stopRecording(bubbleConference: BubbleConference): Promise<void>;
    deleteConferenceRecap(conferenceRecap: BubbleConferenceRecap): Promise<void>;
    deleteConferenceRecordingFile(conferenceRecordingFileId: string): Promise<void>;
    getConferenceRecaps(bubble?: Bubble): Promise<BubbleConferenceRecap[]>;
    filterRecordingFiles(bubble: Bubble): BubbleConferenceRecap[];
    getSharedWithMeConferenceRecordingFilesOld(bubble?: Bubble): Promise<FileDescriptor[]>;
    getSharedWithMeConferenceRecaps(bubble?: Bubble): Promise<BubbleConferenceRecap[]>;
    private correlateSharedFiles;
    getConferenceRecordingAssociatedFiles(conferenceRecordingFile: BubbleConferenceRecap): Promise<FileDescriptor[]>;
    isMyRecord(BubbleConference: any): boolean;
    /** @internal */
    getRecapStatus(recap: BubbleConferenceRecap): Promise<void>;
    /** @internal */
    createRecapLink(recap: BubbleConferenceRecap, linkPrivacy: string, description?: string): Promise<void>;
    /** @internal */
    revokeRecapLink(recap: BubbleConferenceRecap): Promise<void>;
    /** @internal */
    private deleteRecap;
}
//# sourceMappingURL=bubbleConferenceRecording.service.d.ts.map