/**
 * @module Documents
 */
import { Service } from '../../services/service';
import { Bubble, Conversation, DocumentSearchOptions, RBEvent, User } from '../../models';
import { ConsumptionData } from '../files/fileStorage.service';
import { FileDescriptor } from '../../models/common';
import { Subscription } from 'rxjs';
import { Document } from '../../models/document.model';
/**
 * @internal
 */
export declare const DOCUMENTS_SVC = "DocumentsService";
/**
 * @eventProperty
 * Events fired by the DocumentsService
 */
export declare enum DocumentsServiceEvents {
    /**
     * @eventProperty
     * This event is fired when a document is added in the storage
     */
    ON_DOCUMENT_UPLOADED = "ON_DOCUMENT_UPLOADED",
    /**
    * @eventProperty
    * This event is fired when a document is updated (state change or viewer added/removed) in the storage
    */
    ON_DOCUMENT_UPDATED = "ON_DOCUMENT_UPDATED",
    /**
     * @eventProperty
     * This event is fired when a document is removed from the storage
     */
    ON_DOCUMENT_REMOVED = "ON_DOCUMENT_REMOVED",
    /**
     * @eventProperty
     * This event is fired when document storage consumption is updated
     */
    ON_CONSUMPTION_UPDATED = "ON_CONSUMPTION_UPDATED",
    /**
     * @eventProperty
     * This event is fired when document storage usage exceeds 90%.
     */
    ON_CONSUMPTION_WARNING = "ON_CONSUMPTION_WARNING"
}
export interface DocumentConsumptionData extends ConsumptionData {
    /** @internal */
    option?: any;
}
export interface DocumentsService {
    /**
     * This property contains the current usage status of your document storage.
     */
    consumption?: DocumentConsumptionData;
    /**
     * Subscribe to updates from the service (all events are of RBEvent);
     * @param handler - The call-back function that will be subscribed to the RxJS subject
     * @param eventNames - array of event to listen
     */
    subscribe(handler: (event: RBEvent<DocumentsServiceEvents>) => any, eventNames?: DocumentsServiceEvents | DocumentsServiceEvents[]): Subscription;
    /**
     * This factory allows to create Document instance from a JavaScript File
     * @param file - the JavaScript file to manage
     * @throws an RBError (ex: RBErrorCode.STORAGE_NOT_ENOUGH_SPACE_AVAILABLE)
     */
    createDocument(file: File): Promise<Document>;
    /**
     * This method allows you to search for documents in your document storage.
     * The main search criterion is by name, but you can also leave this field empty
     * and use the criteria contained in search options
     * @param search - Used for name searches
     * @param options - Search options
     */
    searchDocuments(options?: DocumentSearchOptions): Promise<Document[]>;
    /**
     * This method retrieves the documents shared in a conversation.
     * For obvious performance reasons, it does not return the full list of documents, but a page of 1000 documents.
     * To retrieve the next page, simply call it up again.
     * @param conversation - the conversation
     */
    getConversationDocuments(conversation: Conversation): Promise<{
        documents: Document[];
        complete: boolean;
    }>;
}
/** @internal */
export declare class DocumentServiceRB extends Service implements DocumentsService {
    private logger;
    private fileStorage;
    private fileServer;
    private eventSubject;
    private subscriptions?;
    private documents;
    static getInstance(): DocumentServiceRB;
    static build(): DocumentServiceRB;
    private constructor();
    start(): Promise<void>;
    reconnect(): Promise<void>;
    stop(): Promise<void>;
    private attachEventHandler;
    subscribe(handler: (event: RBEvent<DocumentsServiceEvents>) => any, eventNames?: DocumentsServiceEvents | DocumentsServiceEvents[]): Subscription;
    sendEvent(name: DocumentsServiceEvents, data?: any): void;
    createDocument(file: File): Promise<Document>;
    hasEnoughSpace(document: Document): boolean;
    uploadDocument(document: Document): Promise<Document>;
    downloadDocument(document: Document): Promise<Blob>;
    abortDocumentTransfert(document: Document): Promise<Document>;
    copyDocument(document: Document): Promise<Document>;
    deleteDocument(document: Document): Promise<void>;
    get consumption(): DocumentConsumptionData;
    addDocumentViewer(document: Document, viewer: User | Bubble): Promise<void>;
    deleteDocumentViewer(document: Document, viewer: User | Bubble): Promise<void>;
    searchDocuments(searchOptions?: DocumentSearchOptions): Promise<Document[]>;
    getConversationDocuments(conversation: Conversation): Promise<{
        documents: Document[];
        complete: boolean;
    }>;
    getFileDescriptorUrl(fd: FileDescriptor): Promise<string>;
    getDocumentById(documentId: string): Promise<Document>;
    private createDocumentFromFileDescriptor;
}
//# sourceMappingURL=documents.service.d.ts.map