import { Subscription } from 'rxjs/internal/Subscription';
import { PersonalRoutine } from '../../models/personalRoutine.model';
import { Service } from '../../services/service';
export declare const PERSONAL_ROUTINES_SVC = "PersonalRoutinesService";
/**
 * @enum {string}
 * @public
 * @readonly
 * @description
 *      Collection of events fired by {@link PersonalRoutinesService}
 */
export declare enum PersonalRoutineEvent {
    /**
     * @public
     * @event PersonalRoutineEvent#RAINBOW_ONPERSONALROUTINELISTUPDATED
     * @description
     *      This event is fired when the personal routine list is updated (at start-up for example)
     */
    RAINBOW_ONPERSONALROUTINELISTUPDATED = "onpersonalroutinelistupdated",
    /**
     * @public
     * @event PersonalRoutineEvent#RAINBOW_ONACTIVATINGPERSONALROUTINE
     * @description
     *      This event is fired when a personal routine is being activated
     */
    RAINBOW_ONACTIVATINGPERSONALROUTINE = "onactivatingpersonalroutine",
    /**
     * @public
     * @event PersonalRoutineEvent#RAINBOW_ONPERSONALROUTINEACTIVATED
     * @description
     *      This event is fired when a personal routine is activated
     * @param {string} routineId ID of routine that has been activated
     */
    RAINBOW_ONPERSONALROUTINEACTIVATED = "onpersonalroutineactivated",
    /**
     * @public
     * @event PersonalRoutineEvent#RAINBOW_ONPERSONALROUTINEUPDATED
     * @description
     *      This event is fired when a personal routine is updated
     * @param {string} routineId ID of routine that has been updated
     */
    RAINBOW_ONPERSONALROUTINEUPDATED = "onpersonalroutineupdated",
    /**
     * @public
     * @event PersonalRoutineEvent#RAINBOW_ONPERSONALROUTINECREATED
     * @description
     *      This event is fired when a personal routine is created
     * @param {string} routineId ID of routine that has been created
     */
    RAINBOW_ONPERSONALROUTINECREATED = "onpersonalroutinecreated",
    /**
     * @public
     * @event PersonalRoutineEvent#RAINBOW_ONPERSONALROUTINEDELETED
     * @description
     *      This event is fired when a personal routine is deleted
     * @param {string} routineId ID of routine that has been deleted
     */
    RAINBOW_ONPERSONALROUTINEDELETED = "onpersonalroutinedeleted"
}
/**
 * @module
 * @name PersonalRoutinesService
 * @public
 * @description
 *      This service manages personal routines
 * @fires PersonalRoutineEvent#RAINBOW_ONPERSONALROUTINEACTIVATED
 * @fires PersonalRoutineEvent#RAINBOW_ONPERSONALROUTINEUPDATED
 */
export declare class PersonalRoutinesService extends Service {
    /*********************************************************/
    /** Services used                                       */
    /*********************************************************/
    private logger;
    private authService;
    private xmppService;
    private profileService;
    private i18nService;
    private errorHelperService;
    private contactService;
    private portalURL;
    private listeners;
    private xmppMessageHandler;
    private _personalRoutines;
    get personalRoutines(): PersonalRoutine[];
    set personalRoutines(value: PersonalRoutine[]);
    private _activatingRoutine;
    get activatingRoutine(): boolean;
    set activatingRoutine(value: boolean);
    private rxSubject;
    static getInstance(): PersonalRoutinesService;
    static build(): PersonalRoutinesService;
    private constructor();
    /************************************************************/
    /** OBSERVABLE STUFF                                       */
    subscribe(callback: any): Subscription;
    sendEvent(type: PersonalRoutineEvent, value: any): void;
    start(): Promise<void>;
    stop(): Promise<void>;
    reconnect(attempt?: number): Promise<void>;
    attachHandlers(): void;
    private onHeadlineMessageReceived;
    private onPersonalRoutineActivation;
    private onPersonalRoutineUpdate;
    private onPersonalRoutineCreated;
    private onPersonalRoutineDeleted;
    /**
     * @public
     * @function getActiveRoutine
     * @description
     *      Get the personal routine currently active
     * @returns {PersonalRoutine} active personal routine object
     * @memberof PersonalRoutinesService
     */
    getActiveRoutine(): PersonalRoutine;
    /**
     * @public
     * @function getFirstNoWorkRoutine
     * @description
     *      Get the first personal routine that is not the default work routine
     * @returns {PersonalRoutine} first personal routine that is not the default work routine
     * @memberof PersonalRoutinesService
     */
    getFirstNoWorkRoutine(): PersonalRoutine;
    /**
     * @public
     * @function getPersonalRoutinesExceptWork
     * @description
     *      Get personal routines of user, except the default work routine
     * @returns {PersonalRoutine[]} array of personal routines
     * @memberof PersonalRoutinesService
     */
    getPersonalRoutinesExceptWork(): PersonalRoutine[];
    getRoutineById(routineId: string): PersonalRoutine;
    /**
     * @public
     * @description Activate a personal routine
     * @returns {Promise<any>} resolves with the routine data from server
     * @memberof PersonalRoutinesService
     * @param {string} routineId id of routine to activate
     * @param {string} [userId] id of the user for which the routine is activated (used by supervisors only). If not set, the user modified is the logged user
     */
    activatePersonalRoutine(routineId: string, userId?: string): Promise<any>;
    /**
     * @public
     * @description
     *      Retrieve a personal routine from server by it's ID
     * @returns {Promise<PersonalRoutine>} resolves with the personal routine
     * @memberof PersonalRoutinesService
     * @param {string} routineId id of routine to retrieve
     * @param {[boolean]} updateLocalData whether we should update local personal routine data. Default value: false
     */
    retrievePersonalRoutineFromServer(routineId: string, updateLocalData?: boolean): Promise<PersonalRoutine>;
    /**
     * @public
     * @description
     *      Retrieve all personal routines from server
     * @returns {Promise<any>} resolves with the personal routines data from server
     * @memberof PersonalRoutinesService
     * @param {[boolean]} updateLocalData whether we should update local personal routine data. Default value: false
     */
    retrieveAllPersonalRoutinesFromServer(updateLocalData?: boolean): Promise<any>;
    /**
     * @public
     * @description
     *      Retrieve all personal routines from server for a given contact
     * @returns {Promise<any>} resolves with the personal routines data from server
     * @memberof PersonalRoutinesService
     * @param {string} userId Identifier of the user for which we want to get the personal routines.
     */
    retrieveAllPersonalRoutinesForContactFromServer(userId: string): Promise<any>;
    /**
     * @public
     * @description
     *      Updates a personal routine data
     * @returns {Promise<any>} resolves with the updated personal routine data from server
     * @memberof PersonalRoutinesService
     * @param {string} routineId id of routine to updata
     * @param {*} data for update
     */
    updatePersonalRoutine(routineId: string, data: any): Promise<any>;
    /**
     * @public
     * @description
     *      Creates a custom personal routine
     * @param {string} name of new personal routine
     * @returns {Promise<any>} resolves with the newly created personal routine data
     * @memberof PersonalRoutinesService
     */
    createCustomPersonalRoutine(name: string): Promise<any>;
    /**
     * @public
     * @description
     *      Delete a custom personal routine
     * @param {string} routineId unique identifier of routine to be deleted
     * @returns {Promise<void>} resolves when routine is deleted
     * @memberof PersonalRoutinesService
     */
    deleteCustomPersonalRoutine(routineId: string): Promise<void>;
}
//# sourceMappingURL=personal-routines.service.d.ts.map