import { Observable } from 'rxjs';
import { Service } from '../../services/service';
import { Poll } from '../../models/poll.model';
import { Bubble } from '../../models/bubble.model';
export declare const POLLS_SVC = "PollsService";
export interface PollsService {
    getRoomPolls(bubbleRef: Bubble | string): Observable<Poll[] | null>;
    getRoomPollById(roomId: string, pollId: string): Poll | undefined;
    createPoll(poll: Poll): Promise<Poll>;
    updatePoll(poll: Poll): Promise<Poll>;
    updatePollFromServer(poll: Poll, format: string): Promise<Poll>;
    getPoll(pollId: string): Promise<Poll>;
    publishPoll(poll: Poll): Promise<Poll>;
    unpublishPoll(poll: Poll): Promise<Poll>;
    deletePoll(poll: Poll): Promise<void>;
    votePoll(poll: Poll): Promise<Poll>;
    terminatePoll(poll: Poll): Promise<Poll>;
    exportAsCSV(poll: Poll, filename: string): Promise<void>;
}
/**
 * @module
 * This service manages polls in Rainbow.
 */
export declare class PollsServiceRB extends Service implements PollsService {
    private mainService;
    private contactService;
    private logger;
    private authService;
    private xmppService;
    private bubbleService;
    private errorHelperService;
    private eventService;
    private xmppSubscription;
    private xmppListeners;
    private pollsObs;
    private started;
    /**
     * Get the pollsService singleton
     * @returns the pollsService singleton
     */
    static getInstance(): PollsServiceRB;
    static build(): PollsServiceRB;
    start(): Promise<void>;
    stop(): Promise<void>;
    reconnect(): Promise<void>;
    private constructor();
    attachListeners(): void;
    /**
     * Get the polls array observable
     * @param bubbleRef - The concerned Bubble
     * @returns an array observable of Polls
     */
    getRoomPolls(bubbleRef: Bubble | string): Observable<Poll[] | null>;
    /**
     * @function getRoomPollsList
     * @public
     * @description Get the polls array (NOT CACHED INTERNAL USE ONLY)
     * @returns {Promise<Poll[]>} the polls array
     * @param {string} roomId The poll room identifier
     */
    getRoomPollsList(roomId: string): Promise<Poll[]>;
    /**
     * @function getPoll
     * @public
     * @description Get the Poll from its identifier
     * @param pollId the Poll identifier
     * @returns the wanted Poll
     */
    getPoll(pollId: string): Promise<Poll>;
    /**
     * @function getRoomPollById
     * @public
     * @description Retrieve Poll object already cached from Poll Id and Room Id
     * @param roomId id of the room
     * @param pollId id of the poll
     * @returns a Poll Object if found
     */
    getRoomPollById(roomId: string, pollId: string): Poll | undefined;
    /**
     * @function updatePollFromServer
     * @public
     * @description Get Poll info from server
     * @param poll the Poll you want info form
     * @param format the format of the Poll you want (small, medium, full)
     * @returns the updated Poll
     */
    updatePollFromServer(poll: Poll, format?: string): Promise<Poll>;
    /**
     * @function publishPoll
     * @public
     * @description Publish the Poll (changing its state to 'published', people will be able to vote, you won't be able to edit the Poll)
     * @param poll the Poll to publish
     * @returns the updated Poll
     */
    publishPoll(poll: Poll): Promise<Poll>;
    /**
     * @function unpublishPoll
     * @public
     * @description Unpublish the Poll (changing its state to 'unpublished', people won't be able to vote but you will be able to edit the Poll)
     * @param poll the Poll to unpublish
     * @returns the updated Poll
     */
    unpublishPoll(poll: Poll): Promise<Poll>;
    /**
     * @function terminatePoll
     * @public
     * @description Terminate a Poll (changing its state to 'terminated', no one will be able to vote anymore)
     * @param poll the Poll to terminate
     * @returns the updated Poll
     */
    terminatePoll(poll: Poll): Promise<Poll>;
    /**
     * @function deletePoll
     * @public
     * @description Delete the Poll
     * @param poll the Poll to delete
     */
    deletePoll(poll: Poll): Promise<void>;
    /**
     * @function createPoll
     * @public
     * @description Create a Poll server side from a Poll object
     * @param poll the Poll to create server side
     * @returns the updated Poll object
     */
    createPoll(poll: Poll): Promise<Poll>;
    /**
     * @function updatePoll
     * @public
     * @description Update a Poll server side from a Poll object
     * @param poll the Poll to update
     * @returns the updated Poll
     */
    updatePoll(poll: Poll): Promise<Poll>;
    /**
     * @function votePoll
     * @public
     * @description Vote for a Poll
     * @param poll the Poll to vote for
     * @returns the updated Poll
     */
    votePoll(poll: Poll): Promise<Poll>;
    private onEventMessage;
    private onRoomMessage;
    exportAsCSV(poll: Poll, filename: string): Promise<void>;
    private getPollUsersStat;
    private getPollQuestionStats;
}
//# sourceMappingURL=polls.service.d.ts.map