/** @module Webinar */
import { Subject } from 'rxjs';
import type { WebinarServiceRB } from "../../services/webinars/webinars.service";
import { Webinar, WebinarMediaType, WebinarSessionParticipant } from "../../models/webinar.model";
export type WebinarConstraintResolution = 'high' | 'medium' | 'low' | 'min';
export interface IWebinarConferenceService {
    join(webinar: Webinar): Promise<Webinar>;
    leave(webinar: Webinar): Promise<Webinar>;
    addAudioVideoMedia(webinar: Webinar, mediaType: string, stream?: MediaStream, replaceBackground?: boolean): Promise<Webinar>;
    addSharingMedia(webinar: Webinar, stream: MediaStream): Promise<Webinar>;
    removeLocalMedia(webinar: Webinar, mediaType: string): Promise<Webinar>;
    muteParticipant(webinar: Webinar, participantId: string, mute: boolean, forced: boolean): Promise<Webinar>;
    putOnStage(webinar: Webinar, participantId: string, media: WebinarMediaType, onStage: boolean, master?: boolean, fullStream?: boolean): Promise<Webinar>;
    shareAudioConfig(webinar: Webinar, audioConfig: string): Promise<Webinar>;
    startWebinar(webinar: Webinar): Promise<Webinar>;
    allowAttendeeToTalk(webinar: Webinar, userId: string): Promise<Webinar>;
    disableAttendeeToTalk(webinar: Webinar, userId: string): Promise<Webinar>;
    askForStaging(webinar: Webinar, participantId: string): Promise<any>;
    declineStagingInvitation(webinar: Webinar, participantId: string): Promise<void>;
    lowerHand(webinar: Webinar, userId: string): Promise<Webinar>;
    raiseHand(webinar: Webinar, userId: string): Promise<Webinar>;
    isActiveWebinar(webinar: Webinar): boolean;
    hasActiveWebinarSession(): boolean;
    disableIncomingStreams(webinar: Webinar, media: 'video' | 'sharing', disabled: boolean): Webinar;
    pauseVideoStream(webinar: Webinar, participant: WebinarSessionParticipant, media: 'video' | 'sharing', paused: boolean, origin: string): Promise<Webinar>;
    waitForGuestXmppReconnection(): Promise<void>;
}
/**
 * This service manages webinar conferences in Rainbow.
 */
export declare class WebinarConferenceService implements IWebinarConferenceService {
    private webinarService;
    startConferencePromiseResolvers: any;
    activeWebinar: Webinar | null;
    activeWebinarSubject: Subject<any>;
    private connected;
    private reconnectingSessionIds;
    private mainService;
    private authService;
    private logger;
    private xmppService;
    private contactService;
    private errorHelperService;
    private speechEnhancementService;
    private eventService;
    private webrtcConfigAndUtils;
    private speechRecognitionService;
    private utilitiesService;
    private deviceManagementService;
    private settingsService;
    private presenceHelperService;
    private profileService;
    private bubbleService;
    private virtualBackgroundService?;
    private groupChatListener;
    private conferenceListener;
    private xmppJingleListener;
    private xmppServiceSubscription;
    private videoServiceSubscription;
    private xmppConnectionSubscription;
    private replaceBackgroundSubscription;
    private deviceManagementSubscription;
    private xmppStagingListener;
    isInteractEventSent: boolean;
    private subscribeToPublisherPromiseResolvers;
    private subscribeToPublisherTimeouts;
    private statsIntervals;
    private promiseQueue;
    private audioMixer;
    /**
     * WebinarConferenceService static factory
     * @param webinarService - the webinarService parent
     */
    static create(webinarService: WebinarServiceRB): WebinarConferenceService;
    /**
     * Private constructor method
     * @param webinarService - the webinarService parent
     */
    private constructor();
    /**
     * Reconnection method, should be call when webinarService is reconnected
     */
    reconnect(): Promise<void>;
    private updateWebinarsFromServer;
    /**
     * Attach all listener to different service, should be called by the webinarService attachListener method
     */
    attachAllListeners(): void;
    detachAllListeners(): void;
    private attachXmppListeners;
    /**
     * Allow to join a webinarSession (entering the conference and established the webrtc connection)
     * @param webinar - the webinar to join
     */
    join(webinar: Webinar): Promise<Webinar>;
    /**
     * Allow to leave a webinar
     *  - remove the user from the stage (if it was on the stage)
     *  - remove the user from the conference (stop the session if last user)
     * @param webinar - the webinar to leave
     * @param forced - when set to true this method stop the session (even if not the last user connect in conf)
     * @param nowait - when set to true this method call async child methods without waiting the end of execution (used in last chance deconnection event mechanism (onunload event))
     * @returns A promise that is resolved when the user has join the conference
     */
    leave(webinar: Webinar, forced?: boolean, nowait?: boolean): Promise<Webinar>;
    /**
     * Allow to remove the "active" webinar
     * @param webinar - the webinar to remove as active
     */
    removeActiveWebinar(webinar: Webinar): void;
    addAudioVideoMedia(webinar: Webinar, media: string, originalStream?: MediaStream, replaceBg?: boolean): Promise<Webinar>;
    getSharingMedia(webinar: Webinar, shouldGetAudioForSharing?: boolean): Promise<void>;
    addSharingMedia(webinar: Webinar, stream: MediaStream): Promise<Webinar>;
    removeLocalMedia(webinar: Webinar, media: string): Promise<Webinar>;
    muteParticipant(webinar: Webinar, participantId: string, mute?: boolean, forced?: boolean): Promise<Webinar>;
    putOnStage(webinar: Webinar, participantId: string, type: WebinarMediaType, onStage: boolean, master?: boolean, fullStream?: boolean): Promise<Webinar>;
    shareAudioConfig(webinar: Webinar, audioConfig: string): Promise<Webinar>;
    startWebinar(webinar: Webinar): Promise<Webinar>;
    stopWebinar(webinar: Webinar): Promise<Webinar>;
    raiseHand(webinar: Webinar, userId: string): Promise<Webinar>;
    lowerHand(webinar: Webinar, userId: string): Promise<Webinar>;
    allowAttendeeToTalk(webinar: Webinar, userId: string): Promise<Webinar>;
    disableAttendeeToTalk(webinar: Webinar, userId: string): Promise<Webinar>;
    activateWebinarSound(webinar: Webinar): Promise<void>;
    askForStaging(webinar: Webinar, participantId: string): Promise<void>;
    declineStagingInvitation(webinar: Webinar, participantId: string): Promise<void>;
    hasActiveWebinarSession(): boolean;
    isActiveWebinar(webinar: Webinar): boolean;
    disableAudioVideoMedia(webinar: Webinar): Promise<void>;
    disableSharingMedia(webinar: Webinar): void;
    enableSubtitles(webinar: Webinar, enable: boolean): void;
    applyVideoConstraints(webinar: Webinar, streamType: 'audioVideo' | 'sharing', resolution: WebinarConstraintResolution, frameRate: number, maxBitrate: number): Promise<void>;
    resendStageEvents(webinar: Webinar): Promise<void>;
    private computeScaleFactor;
    disableIncomingStreams(webinar: Webinar, media: 'video' | 'sharing', disabled: boolean): Webinar;
    pauseVideoStream(webinar: Webinar, participant: WebinarSessionParticipant, media: 'video' | 'sharing', paused: boolean, origin: string): Promise<Webinar>;
    waitForGuestXmppReconnection(): Promise<void>;
    private startSession;
    private joinSession;
    private manageCodecs;
    private stopSession;
    private disconnectParticipant;
    private onGroupchatMessage;
    private ackAllMessages;
    private onXmppJingleMessage;
    private onAskStagingMessage;
    private onConferenceMessage;
    private handleAudioConfig;
    private handleRecording;
    private handleStage;
    private updateStage;
    private getWebinarSnapshot;
    private subscribeToPublisher;
    private subscribeToPublisherInternal;
    private createSessionParticipantFromElem;
    private createSessionParticipantFromAttendeeJid;
    private onVideoServiceEvent;
    private onJingleMessage;
    private onJingleSessionStateChange;
    private scheduleSubscribeToPublisher;
    private scheduleTransportReplace;
    private sendTransportReplaceForSession;
    private terminateJingleSession;
    private onJingleSessionInitiate;
    private onJingleSessionTerminated;
    private onJingleContentAdd;
    private onJingleContentModify;
    private onJingleMediaModified;
    private onJingleContentRemove;
    private setBusyState;
    private onJingleStatsChange;
    private onJingleResubscriptionNeededEvent;
    private onJingleErrorEvent;
    private onXmppConnectionChangeEvent;
    private onReplaceBackgroundChangeEvent;
    private onMediaDeviceChangeEvent;
    private startStatsForSession;
    private stopStatsForSession;
    private stopStatsForAllSessions;
    private addSubscribeToPublisherTimeout;
    private clearSubscribeToPublisherTimeout;
    private clearSubscribeToPublisherTimeouts;
    private resubscribe;
    private clearWebinar;
    private clearSession;
}
//# sourceMappingURL=webinarConference.service.d.ts.map