import { Subscription } from "rxjs";
import { CallRB } from "../../models/call.model";
import { Service } from "../../services/service";
export declare const WEBRTC_CONFIG_UTILS_SVC = "WebrtcConfigAndUtils";
export interface WebrtcStatisticsNetwork {
    /**
     * Type of interface usedCan be "wifi", "vpn", "ethernet", "unknown", "cellular"
     * From networkType in local-candidate report
     */
    networkType?: string;
    /**
     * Route used by the peer-connectionFormat: <local_address>: [type] (protocol) <-> <remote_address>: [type] (protocol)
     * Computed from statistics in local_candidate and remote_candidate depending on the localCandidateId and remoteCandidateId in the candidate-pair report in use (selectedCandidatePairId in tranport report or selected=true in candidate-pair report
     */
    candidatePair?: string;
}
/**
 * Object containing all stats related to the output-rtp (outflow)
 */
export interface WebrtcStatisticsOutboundAudio {
    /**
     * The total of packets sent from the beginning of this RTP stream.From packetsSent in outbound-rtp report
     */
    totalPacketsSent?: number;
    /**
     * The total of bytes sent from the beginning of this RTP stream.From bytesSent outbound-rtp report
     */
    totalBytesSent?: number;
    /**
     * The delta of the audio KB sent between the current and the last iteration
     */
    deltaAudioKBSent?: number;
    /**
     * The current encoder target in bits per second for this RTP stream.From targetBitrate in outbound-rtp report
     */
    targetBitrate?: number;
    /**
     * Represents the audio level of the media source detected from the input device
     */
    audioInputLevel?: number;
    /**
     * If exist, the value of the media identification-tag negotiated for this RTP streamFrom mid in inbound-rtp or outbound-rtp report
     */
    mid?: number;
    /**
     * Name of the inbound codec used (eg: "opus")
     * Computed from mimeType (remove "audio/") in the codec report associated to this RTP Stream (codecId from the inbound-rtp report)
     */
    codec?: string;
}
/**
 * Object containing all stats related to the inbound-rtp (inflow)
 */
export interface WebrtcStatisticsInboundAudio {
    /**
     * The total of packets received from the beginning of this RTP stream.From packetsReceived in inbound-rtp report
     */
    totalPacketsReceived?: number;
    /**
     * The total of packets discarded from the beginning of this RTP stream.From packetsDiscarded in inbound-rtp report
     */
    totalPacketsReceivedDiscarded?: number;
    /**
     * The total of packets lost from the beginning of this RTP stream.From packetsLost in inbound-rtp report
     */
    totalPacketsLost?: number;
    /**
     * The total of bytes received from the beginning of this RTP stream.From bytesReceived inbound-rtp report
     */
    totalBytesReceived?: number;
    /**
     * The number of packets received for this RTP stream from the last measurement. Computed from packetsReceived in inbound-rtp report
     */
    deltaPacketsReceived?: number;
    /**
     * The number of KB received for this RTP stream since the last measurement.
     */
    deltaKBReceived?: number;
    /**
     * Mean of the round trip time during the last interval.Computed from totalRoundTripTime and roundTripTimeMeasurements in remote-outbound-rtp report
     */
    roundTripTimeMs?: number;
    /**
     * Mean of the jitter buffer delay during the last interval.Computed From jitterBufferDelay and jitterBufferEmittedCount in inbound-rtp report
     */
    jitterBufferMs?: number;
    /**
     * Value of the jitter for the current measurement.From jitter in inbound-rtp report
     */
    jitterMs?: number;
    /**
     * Mean for the last interval. Computed from the codec used, the absolute delay computed and the packets lost.
     */
    mos?: number;
    /**
     * Name of the inbound codec used (eg: "opus")
     * Computed from mimeType (remove "audio/") in the codec report associated to this RTP Stream (codecId from the inbound-rtp report)
     */
    codec?: string;
    /**
     * If exist, the value of the media identification-tag negotiated for this RTP streamFrom mid in inbound-rtp or outbound-rtp report
     */
    mid?: number;
    /**
     * The MEAN MOS value for the current session
     */
    meanMOS?: number;
    /**
     * Represents the audio level of the media source seen from the output device
     */
    audioOutputLevel?: number;
    /**
     * Represents the absolute delay computed with: absoluteDelay:number = 20 + RTT/2 + JitterBufferDelay where
     * 20 represents the packetization time (fixed value) in milliseconds
     * RTT as computed in Compute the Round Trip Time in milliseconds
     * JitterBufferDelay in milliseconds
     */
    absDelayMs?: number;
    /**
     * A value indicating the current quality of the incoming audio based on the MOS value; Values are 0, 1, 2; as 0 is bad, 3 is good
     */
    networkQualityValue?: number;
}
/**
 * Interface containing all stats related to the audio stats for the sessions output-rtp (outflow) + input-rtp (inflow)
 */
export interface WebrtcStatisticsAudio {
    /**
     * Object containing all stats related to the output-rtp (outflow)
     */
    sent?: WebrtcStatisticsOutboundAudio;
    /**
     * Object containing all stats related to the inbound-rtp (inflow)
     */
    received?: WebrtcStatisticsInboundAudio;
}
/**
 * Interface containing all stats related to the OUTBOUND video stats for the sessions
 * NOTE The same interface is also related to the screen sharing, as in terms of WEBRTC it's a VIDEO stream
 */
export interface WebrtcStatisticsOutboundVideo {
    /**
     * The total of packets sent from the beginning of this RTP stream. From packetsSent in outbound-rtp report
     */
    totalPacketsSent?: number;
    /**
     * The total of bytes sent from the beginning of this RTP stream. From bytesSent outbound-rtp report
     */
    totalBytesSent?: number;
    /**
     * The total time for encoding the media from the beginning of this RTP stream. From totalEncodeTime in outbound-rtp report
     */
    totalEncodeTimeSeconds?: number;
    /**
     * The total number of video frames sent from the beginning of this RTP stream. From framesSent in outbound-rtp report
     */
    totalFramesSent?: number;
    /**
     * The number of frames that were successfully encoded from the beginning of this RTP stream.From framesEncoded in outbound-rtp report
     */
    totalFramesEncoded?: number;
    /**
     * The number of key frames that were successfully encoded from the beginning of this RTP stream.From keyFramesEncoded in outbound-rtp report
     */
    totalKeyFramesEncoded?: number;
    /**
     * The number of Picture Loss Indication (PLI) requests sent (receiver) or received (sender) from the beginning of this RTP stream.
     * From pliCount in outbound-rtp report
     */
    totalPliCount?: number;
    /**
     * The number of Negative Acknowledgment (NACK) requests sent from the beginning of this RTP stream. From nackCount in outbound-rtp report
     */
    totalNackCount?: number;
    /**
     * The current encoder target in bits per second for this RTP stream.From targetBitrate in outbound-rtp report
     */
    targetBitrate?: number;
    /**
     * The number of horizontal pixels in a video frame for this RTP stream.From frameWidth in inbound-rtp or outbound-rtp report
     */
    frameWidth?: number;
    /**
     * The number of vertical pixels in a video frame for this RTP stream.From frameHeigh in inbound-rtp or outbound-rtp report
     */
    frameHeight?: number;
    /**
     * The number of individual video frames sent per second at a given time.
     */
    framesPerSecond?: number;
    /**
     * The current reason for limiting the resolution and/or framerate. Acceptable values: bandwidth, cpu, other, none.
     */
    qualityLimitationReason?: string;
    /**
     * Object containing the details about all quality limitations durations during the session
     */
    qualityLimitationDurations?: any;
    /**
     * If exist, the value of the media identification-tag negotiated for this RTP streamFrom mid in inbound-rtp or outbound-rtp report
     */
    mid?: number;
    /**
     * The rate of retransmitted packets sent per second.
     * This metric is useful for evaluating the stability and quality of a WebRTC connection by indicating how many packets needed to be resent to maintain data integrity.
     */
    retransmittedPacketsSent?: number;
    /**
     * The average Quantization Parameter (QP) used for encoding a video stream, normalized by the number of frames encoded.
     * The Quantization Parameter (QP) is a crucial factor in video compression and directly affects the quality and bitrate of the video.
     * The Quantization Parameter (QP) controls the level of compression during video encoding. Lower QP values (e.g., around 10-20) correspond to higher video quality because the encoding process uses more bits to represent each frame.
     * Higher QP values (e.g., 30-50) result in higher compression and lower video quality, as fewer bits are used per frame.
     */
    qpValue?: number;
    /**
     * Name of the codec used (eg: "vp8")Computed from mimeType (remove "audio/") in the codec report associated to this RTP Stream (codecId from the inbound-rtp report)
     */
    codec?: string;
}
/**
 * Interface containing all stats related to the INBOUND video stats for the sessions
 * NOTE The same interface is also related to the screen sharing, as in terms of WEBRTC it's a VIDEO stream
 */
export interface WebrtcStatisticsInboundVideo {
    /**
     * The total of packets received from the beginning of this RTP stream. From packetsReceived in inbound-rtp report
     */
    totalPacketsReceived?: number;
    /**
     * The total of packets discarded from the beginning of this RTP stream.From packetsDiscarded in inbound-rtp report
     */
    totalPacketsReceivedDiscarded?: number;
    /**
     * The total of packets lost from the beginning of this RTP stream.From packetsLost in inbound-rtp report
     */
    totalPacketsLost?: number;
    /**
     * The total of bytes received from the beginning of this RTP stream.From bytesReceived inbound-rtp report
     */
    totalBytesReceived?: number;
    /**
     * The number of KB received for this RTP stream since the last measurement.
     */
    deltaKBReceived?: number;
    /**
     * The total time for decoding the media from the beginning of this RTP stream.From totalDecodeTime in inbound-rtp report
     */
    totalDecodeTimeSeconds?: number;
    /**
     * The total number of video frames received from the beginning of this RTP stream.From framesReceived in inbound-rtp report
     */
    totalFramesReceived?: number;
    /**
     * The number of frames that were successfully decoded from the beginning of this RTP stream.From framesDecoded in inbound-rtp report
     */
    totalFramesDecoded?: number;
    /**
     * The number of key frames that were successfully decoded from the beginning of this RTP stream.From keyFramesDecoded in inbound-rtp report
     */
    totalKeyFramesDecoded?: number;
    /**
     * The number of frames that were received but not displayed or processed (e.g., due to delays or quality degradation) from the beginning of this RTP stream.
     * From framesDropped in inbound-rtp report
     */
    totalFramesDropped?: number;
    /**
     * The number of video freeze experienced by the receiver from the beginning of this RTP stream.From freezeCount in inbound-rtp report
     */
    totalFreezeCount?: number;
    /**
     * The number of Picture Loss Indication (PLI) requests sent (receiver) or received (sender) from the beginning of this RTP stream.
     */
    totalPliCount?: number;
    /**
     * The number of Negative Acknowledgment (NACK) requests sent from the beginning of this RTP stream.From nackCount in outbound-rtp report
     */
    totalNackCount?: number;
    /**
     * The number of horizontal pixels in a video frame for this RTP stream.From frameWidth in inbound-rtp or outbound-rtp report
     */
    frameWidth?: number;
    /**
     * The number of vertical pixels in a video frame for this RTP stream. From frameHeigh in inbound-rtp or outbound-rtp report
     */
    frameHeight?: number;
    /**
     * The number of individual video frames received per second at a given time.
     */
    framesPerSecond?: number;
    /**
     * If exist, the value of the media identification-tag negotiated for this RTP streamFrom mid in inbound-rtp or outbound-rtp report
     */
    mid?: number;
    /**
     * The number of times the media playback has been paused. A pause can happen due to various reasons, including network conditions, user actions, or system-level issues such as performance bottlenecks.
     */
    pauseCount?: number;
    /**
     * Name of the codec used (eg: "vp8")Computed from mimeType (remove "audio/") in the codec report associated to this RTP Stream (codecId from the inbound-rtp report)
     */
    codec?: string;
}
/**
 * Interface containing all stats related to the video stats for the sessions inbound/outbound
 * NOTE The same interface is also related to the screen sharing, as in terms of WEBRTC it's a VIDEO stream
 */
export interface WebrtcStatisticsVideo {
    /**
     * Object containing all stats related to the outbound-rtp (outflow)
     * NB In case of SIMULCAST (only available for Bubble Conferences), there're 3 substreams send to the distant party ("l", "m", "h" for low, medium, high);
     */
    sent?: WebrtcStatisticsOutboundVideo | {
        "l": WebrtcStatisticsOutboundVideo;
        "m": WebrtcStatisticsOutboundVideo;
        "h": WebrtcStatisticsOutboundVideo;
    };
    /**
     * Object containing all stats related to the inbound-rtp (inflow)
     */
    received?: WebrtcStatisticsInboundVideo;
}
/**
 * The type of the session
 */
export declare enum WebrtcStatisticsType {
    CONFERENCE = "Conference",
    WEBINAR = "Webinar",
    P2P = "P2P"
}
/**
 * The current media type of the session based on the kind of Media Streams inside
 */
export declare enum WebrtcStatisticsMediaType {
    /**
     * Audio only
     */
    AUDIO = "AUDIO",
    /**
     * BUNDLE (audio + video)
     */
    BUNDLE = "BUNDLE",
    /**
     * Video only
     */
    VIDEO = "VIDEO",
    /**
     * Screen Sharing only
     */
    SHARING = "SHARING"
}
/**
 * The type of the session in terms of media direction: publisher only / receiver only / both
 */
export declare enum WebrtcStatisticsSessionType {
    /**
     * Subscriber and publisher (bidirectionnal)
     */
    PUBSUB = "PUBSUB",
    /**
     * Subscriber (or receiver) of the media
     */
    SUBSCRIBER = "SUBSCRIBER",
    /**
     * Publisher of the media
     */
    PUBLISHER = "PUBLISHER"
}
export interface WebrtcStatisticsData {
    /**
     * The current iteration number of getting the statistics
     */
    iteration?: number;
    /**
     * The interval duration getting the statistics
     */
    intervalDuration?: number;
    /**
     * The type of the session related to the statistics;
     */
    type?: WebrtcStatisticsType;
    /**
     * In case the session is part of a bubble conference or webinar
     */
    conferenceId?: string;
    /**
     * The session media type
     */
    mediaType?: WebrtcStatisticsMediaType;
    /**
     * The session type
     */
    sessionType?: WebrtcStatisticsSessionType;
    /**
     * The audio data, if available
     */
    audio?: WebrtcStatisticsAudio;
    /**
     * The video data, if available
     */
    video?: WebrtcStatisticsVideo;
    /**
     * The sharing data, if available
     */
    sharing?: WebrtcStatisticsVideo;
    /**
     * The network data, if available
     */
    network?: WebrtcStatisticsNetwork;
    /**
     * In case of web conference, the remote publisher id
     */
    publisherId?: string;
    /**
     * In case of web conference, the remote publisher name (anonymized)
     */
    publisherName?: string;
}
export interface IWebrtcConfigAndUtils {
    RTC: any;
}
/**
 * This module contains all the webrtc configuration tools and utils that can be used to manages webrtc audio/video calls
 * This module can be used to set the video quality and frame rate for all P2P calls
 * The lifecycle of this module is managed by the WebRTC P2P Service
 */
export declare class WebrtcConfigAndUtils extends Service implements IWebrtcConfigAndUtils {
    /**
     * The current webrtc configuration used (TURN servers and DC)
     */
    webrtcConfig: any;
    /**
     * The current webrtc company configuration (if set for the company)
     */
    companyConfig: any;
    /**
     * The current webrtc video and sharing quality configuration when in call with mobile phone
     */
    mobileVideoQualityConfiguration: {
        video: {
            fixedFrameRate: number;
            fixedVideoWidth: number;
            fixedVideoHeight: number;
        };
        sharing: {
            fixedFrameRate: number;
            fixedVideoWidth: number;
            fixedVideoHeight: number;
        };
    };
    /**
     * The current webrtc video and sharing quality configuration
     */
    videoQualityConfiguration: {
        video: {
            fixedFrameRate: number;
            fixedVideoWidth: number;
            fixedVideoHeight: number;
        };
        sharing: {
            fixedFrameRate: number;
            fixedVideoWidth: number;
            fixedVideoHeight: number;
        };
    };
    /**
     * The RTC object that contains the attach and detach functions to add stream to DOM element based on the platform
     * The attachSessionMediaToElement is used for session that have only 1 media (for conferences case); We need to send the HTML element ID + the session that we want to "attach" to that element
     */
    RTC: any;
    /**
     * Subscribe to updates on the current calls sessions (all events are of RBEvent type {name: string, data:any});
     * All public events that are fired by this service are described in the documentation.
     * NB There might be some events that are not documented here, they should be ignored
     * @param handler - The call-back function that will be subscribed to the RxJS subject
     */
    subscribe(handler: any): Subscription;
    /**
     * Send an event to the RX Subject (sends always a RBEvent type)
     * @param string - name The name of the event
     * @param data - The data of the event
     */
    private sendEvent;
    /**
     * The Calls Stats object that contains all the statistics for the current call (that will be uploaded to the server at the end of the call)
     */
    callsStats: {};
    askToAddSharing(__conversationId: string, __shouldAskForAudio?: boolean): boolean;
    private logger;
    private settingsService;
    private authService;
    private xmppService;
    private mainService;
    private contactService;
    private eventService;
    private deviceManagementService;
    private profileService;
    private rxSubject;
    private ttl;
    private ttlTimeout;
    private started;
    private statsWaitingQueue;
    static getInstance(): WebrtcConfigAndUtils;
    static build(): WebrtcConfigAndUtils;
    private constructor();
    start(): Promise<void>;
    stop(): void;
    private onConnectionStateChangeEvent;
    getBrowserMethodHandler(): any;
    setBrowserMethodHandler(): any;
    getDesktopSharingSource(): any;
    private getConstraintsForMedia;
    getBrowserMedia(userMedia: any[], fixedVideoWidth?: number, fixedVideoHeight?: number, fixedFrameRate?: number, referer?: any, getAudioForSharing?: boolean): Promise<MediaStream | undefined>;
    /**
     * Disables and removes all local streams for this session
     * @param session - The session (or any object that contains localStreams that will be removed)
     */
    disableAllStreamsForSession(session: any): void;
    /**
     * Disables MediaStream
     * @param streams - An array of MediaStream to be stopped and removed
     */
    disableMediaStreams(streams: MediaStream[]): void;
    /**
     * Disables MediaStream
     * @param stream - The MediaStream to be stopped and removed
     */
    disableMediaStream(stream: MediaStream): void;
    getMobileMediaConstraints(type: string): any;
    createOrUpdateStatisticsForCall(call: CallRB): Promise<void>;
    updateStatisticsForCall(id: string, callId: string, callState: string, metrics: any): Promise<void>;
    createStatisticsForSession(callId: string, peerId: string, callState: string): Promise<string>;
    setWebrtcConfiguration(): Promise<void>;
    /**
     * Get the Media stream from the browser w/o any constraints (except for the selected current device);
     * @param userMedia - An array of medias to get (accepted values inside the array are : "audio" and "video");
     */
    getBrowserMediaWithNoConstraints(userMedia: string[]): Promise<MediaStream>;
    private getDefaultConstraintsForMedia;
    private setIceConfig;
    private manageIceServers;
    private getIceConfig;
    private setCompanyWebrtcConfig;
    private setVideoQualityConfigurationForCompany;
    private getCompanyWebrtcConfig;
    getStatsForSession(session: any, interval?: number): number;
    private getStatsFromData;
}
//# sourceMappingURL=webrtcConfigAndUtils.d.ts.map